@@ -18,11 +18,22 @@ def validate():
 @validate.command('model')
 @click.argument('model-json', type=click.Path(
     exists=True, file_okay=True, dir_okay=False, resolve_path=True))
+@click.option(
+    '--plain-text/--json', ' /-j', help='Flag to note whether the output validation '
+    'report should be formatted as a JSON object instead of plain text. If set to JSON, '
+    'the output object will contain several attributes. The "honeybee_core" and '
+    '"honeybee_schema" attributes will note the versions of these libraries used in '
+    'the validation process. An attribute called "fatal_error" is a text string '
+    'containing an exception if the Model failed to serialize and will be an empty '
+    'string if serialization was successful. An attribute called "errors" will '
+    'contain a list of JSON objects for each invalid issue found in the model. A '
+    'boolean attribute called "valid" will note whether the Model is valid or not.',
+    default=True, show_default=True)
 @click.option(
     '--output-file', '-f', help='Optional file to output the full report '
     'of any errors detected. By default it will be printed out to stdout',
     type=click.File('w'), default='-')
-def validate_model(model_json, output_file):
+def validate_model(model_json, plain_text, output_file):
     """Validate all properties of a Model JSON file against the Honeybee schema.
 
     This includes basic properties like adjacency checks and all geometry checks.
@@ -32,22 +43,39 @@ def validate_model(model_json, output_file):
         model_json: Full path to a Model JSON file.
     """
     try:
-        # re-serialize the Model to make sure no errors are found in re-serialization
-        click.echo(
-            'Validating Model using honeybee-core=={} and honeybee-schema=={}'.format(
-                folders.honeybee_core_version_str, folders.honeybee_schema_version_str
-            ))
-        parsed_model = Model.from_hbjson(model_json)
-        click.echo('Re-serialization passed.')
-        # perform several other checks for geometry rules and others
-        report = parsed_model.check_all(raise_exception=False)
-        click.echo('Model checks completed.')
-        # check the report and write the summary of errors
-        if report == '':
-            output_file.write('Congratulations! Your Model is valid!')
+        if plain_text:
+            # re-serialize the Model to make sure no errors are found
+            click.echo(
+                'Validating Model using honeybee-core=={} and honeybee-schema=={}'.format(
+                    folders.honeybee_core_version_str, folders.honeybee_schema_version_str
+                ))
+            parsed_model = Model.from_hbjson(model_json)
+            click.echo('Re-serialization passed.')
+            # perform several other checks for geometry rules and others
+            report = parsed_model.check_all(raise_exception=False, detailed=False)
+            click.echo('Model checks completed.')
+            # check the report and write the summary of errors
+            if report == '':
+                output_file.write('Congratulations! Your Model is valid!')
+            else:
+                error_msg = '\nYour Model is invalid for the following reasons:'
+                output_file.write('\n'.join([error_msg, report]))
         else:
-            error_msg = '\nYour Model is invalid for the following reasons:'
-            output_file.write('\n'.join([error_msg, report]))
+            out_dict = {
+                'honeybee_core': folders.honeybee_core_version_str,
+                'honeybee_schema': folders.honeybee_schema_version_str
+            }
+            try:
+                parsed_model = Model.from_hbjson(model_json)
+                out_dict['fatal_error'] = ''
+                out_dict['errors'] = \
+                    parsed_model.check_all(raise_exception=False, detailed=True)
+                out_dict['valid'] = True if len(out_dict['errors']) == 0 else False
+            except Exception as e:
+                out_dict['fatal_error'] = str(e)
+                out_dict['errors'] = []
+                out_dict['valid'] = False
+            output_file.write(json.dumps(out_dict, indent=4))
     except Exception as e:
         _logger.exception('Model validation failed.\n{}'.format(e))
         sys.exit(1)
