@@ -317,7 +317,7 @@ class Shade(_Base):
                 'Shade "{}" is invalid with dimensions less than the '
                 'tolerance.\n{}'.format(self.full_id, e))
 
-    def check_planar(self, tolerance=0.01, raise_exception=True):
+    def check_planar(self, tolerance=0.01, raise_exception=True, detailed=False):
         """Check whether all of the Shade's vertices lie within the same plane.
 
         Args:
@@ -326,17 +326,21 @@ class Shade(_Base):
                 Default: 0.01, suitable for objects in meters.
             raise_exception: Boolean to note whether an ValueError should be
                 raised if a vertex does not lie within the object's plane.
+            detailed: Boolean for whether the returned object is a detailed list of
+                dicts with error info or a string with a message. (Default: False).
+
+        Returns:
+            A string with the message or a list with a dictionary if detailed is True.
         """
         try:
             self.geometry.check_planar(tolerance, raise_exception=True)
         except ValueError as e:
             msg = 'Shade "{}" is not planar.\n{}'.format(self.full_id, e)
-            if raise_exception:
-                raise ValueError(msg)
-            return msg
-        return ''
+            return self._validation_message(msg, raise_exception, detailed, '0101')
+        return [] if detailed else ''
 
-    def check_self_intersecting(self, tolerance=0.01, raise_exception=True):
+    def check_self_intersecting(self, tolerance=0.01, raise_exception=True,
+                                detailed=False):
         """Check whether the edges of the Shade intersect one another (like a bowtie).
 
         Args:
@@ -345,21 +349,24 @@ class Shade(_Base):
                 suitable for objects in meters.
             raise_exception: If True, a ValueError will be raised if the object
                 intersects with itself. Default: True.
+            detailed: Boolean for whether the returned object is a detailed list of
+                dicts with error info or a string with a message. (Default: False).
+
+        Returns:
+            A string with the message or a list with a dictionary if detailed is True.
         """
         if self.geometry.is_self_intersecting:
             msg = 'Shade "{}" has self-intersecting edges.'.format(self.full_id)
             try:  # see if it is self-intersecting because of a duplicate vertex
                 new_geo = self.geometry.remove_colinear_vertices(tolerance)
                 if not new_geo.is_self_intersecting:
-                    return ''  # removing the duplicate vertex makes it self-intersecting
+                    return [] if detailed else ''  # valid with removed dup vertex
             except AssertionError:
                 pass  # zero area face; treat it as self-intersecting
-            if raise_exception:
-                raise ValueError(msg)
-            return msg
-        return ''
+            return self._validation_message(msg, raise_exception, detailed, '0102')
+        return [] if detailed else ''
 
-    def check_non_zero(self, tolerance=0.0001, raise_exception=True):
+    def check_non_zero(self, tolerance=0.0001, raise_exception=True, detailed=False):
         """Check whether the area of the Shade is above a certain "zero" tolerance.
 
         Args:
@@ -368,14 +375,17 @@ class Shade(_Base):
                 above the smallest size that OpenStudio will accept.
             raise_exception: If True, a ValueError will be raised if the object
                 area is below the tolerance. Default: True.
+            detailed: Boolean for whether the returned object is a detailed list of
+                dicts with error info or a string with a message. (Default: False).
+
+        Returns:
+            A string with the message or a list with a dictionary if detailed is True.
         """
         if self.area < tolerance:
             msg = 'Shade "{}" geometry is too small. Area must be at least {}. ' \
                 'Got {}.'.format(self.full_id, tolerance, self.area)
-            if raise_exception:
-                raise ValueError(msg)
-            return msg
-        return ''
+            return self._validation_message(msg, raise_exception, detailed, '0103')
+        return [] if detailed else ''
 
     @property
     def to(self):
